summary refs log tree commit diff
path: root/src/libnm-client-impl/nm-device.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/libnm-client-impl/nm-device.c')
-rw-r--r--src/libnm-client-impl/nm-device.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/libnm-client-impl/nm-device.c b/src/libnm-client-impl/nm-device.c
index 2d3be64c..dc868f5b 100644
--- a/src/libnm-client-impl/nm-device.c
+++ b/src/libnm-client-impl/nm-device.c
@@ -1283,7 +1283,7 @@ nm_device_get_type_description(NMDevice *device)
  * Gets the devices currently set as port of @device.
  *
  * Returns: (element-type NMDevice): the #GPtrArray containing #NMDevices that
  * are slaves of @device. This is the internal copy used by the device and
  * must not be modified.
  *
  * Since: 1.34
@@ -1397,8 +1397,8 @@ _nm_device_notify_update_prop_ports(NMClient               *client,
     nm_assert(notify_update_prop_flags == NML_DBUS_NOTIFY_UPDATE_PROP_FLAGS_NOTIFY);
 
     klass = NM_DEVICE_GET_CLASS(self);
-    if (klass->slaves_param_spec)
-        _nm_client_queue_notify_object(client, self, klass->slaves_param_spec);
+    if (klass->ports_param_spec)
+        _nm_client_queue_notify_object(client, self, klass->ports_param_spec);
 out:
     return NML_DBUS_NOTIFY_UPDATE_PROP_FLAGS_NONE;
 }
@@ -1283,7 +1283,7 @@ nm_device_get_type_description(NMDevice *device)
  *
  * Returns: (element-type NMDevice): the #GPtrArray containing #NMDevices that
- * are slaves of @device. This is the internal copy used by the device and
+ * are ports of @device. This is the internal copy used by the device and
  * must not be modified.
  *